sonarcal

Skip to content

# User Manual

Note

This manual is under development.

Info

If you opened this documentation from the sonarcal program you will be reading the offline version. The online version is available here.

## Introduction

This is the user documentation for the sonarcal program.

It supports viewing and deriving beam gain calibrations from omni-directional sonars:

Manufacturer | Model | Supported file formats
--- | --- | ---
Furuno | XXX | sonar-netCDF4
Kongsberg Discovery | SU90 | sonar-netCDF4
Kongsberg Discovery | CS90 | raw, sonar-netCDF4
Kongsberg Discovery | SN90 | raw, sonar-netCDF4

Other sonars that output sonar-netCDF4 files may also work, but there can often be small adjustments needed for full support.

The development of the current form of this program was supported by AZTI. Earlier versions were developed while the author was employed at the Norwegian Institute of Marine Research.

## How to use

The main operation screen.

The seconday display of ping amplitudes.

## Configuration

some text

## Export of data

some text